summaryrefslogtreecommitdiff
path: root/include/mupdf/fitz/bidi.h
diff options
context:
space:
mode:
authorTor Andersson <tor.andersson@artifex.com>2016-04-05 12:31:26 +0200
committerTor Andersson <tor.andersson@artifex.com>2016-04-05 13:40:04 +0200
commita45b3a21c67476c703ddd5d5b4755364671c26c1 (patch)
treea755086e3fa8dd4a11d044f7765875b6f6ad0e19 /include/mupdf/fitz/bidi.h
parent353a05d9e8e8023e1c3c24816f712bdcb05502ca (diff)
downloadmupdf-a45b3a21c67476c703ddd5d5b4755364671c26c1.tar.xz
Clean up bidi enum names.
And use the same enum for both the internal bidi code and the layout code.
Diffstat (limited to 'include/mupdf/fitz/bidi.h')
-rw-r--r--include/mupdf/fitz/bidi.h21
1 files changed, 6 insertions, 15 deletions
diff --git a/include/mupdf/fitz/bidi.h b/include/mupdf/fitz/bidi.h
index f458c498..e5cb87ed 100644
--- a/include/mupdf/fitz/bidi.h
+++ b/include/mupdf/fitz/bidi.h
@@ -23,9 +23,9 @@
typedef enum fz_bidi_direction_e
{
- BIDI_LEFT_TO_RIGHT = 0,
- BIDI_RIGHT_TO_LEFT = 1,
- BIDI_NEUTRAL = 2
+ FZ_BIDI_LTR = 0,
+ FZ_BIDI_RTL = 1,
+ FZ_BIDI_NEUTRAL = 2
}
fz_bidi_direction;
@@ -36,16 +36,8 @@ typedef enum fz_bidi_flags_e
}
fz_bidi_flags;
-typedef uint8_t fz_bidi_chartype;
-typedef int fz_bidi_level; /* Note: Max level is 125 */
-
-enum
-{
- BIDI_LEVEL_MAX = 125 /* Updated for 6.3.0 */
-};
-
/**
- * Prototype for callback function supplied to Bidi_fragmentText.
+ * Prototype for callback function supplied to fz_bidi_fragment_text.
*
* @param fragment first character in fragment
* @param fragmentLen number of characters in fragment
@@ -76,8 +68,7 @@ typedef void (fz_bidi_fragment_callback)(const uint32_t *fragment,
*
* @param[in] text start of Unicode sequence
* @param[in] textlen number of Unicodes to analyse
* @param[in] baseDir direction of paragraph (specify BIDI_NEUTRAL
* to force auto-detection)
* @param[in] callback function to be called for each fragment
* @param[in] arg data to be passed to the callback function
* @param[in] flags flags to control operation (see fz_bidi_flags above)
@@ -90,4 +81,4 @@ void fz_bidi_fragment_text(fz_context *ctx,
void *arg,
int flags);
-#endif /* FITZ_BIDI_H */
+#endif
@@ -76,8 +68,7 @@ typedef void (fz_bidi_fragment_callback)(const uint32_t *fragment,
* @param[in] text start of Unicode sequence
* @param[in] textlen number of Unicodes to analyse
- * @param[in] baseDir direction of paragraph (specify BIDI_NEUTRAL
- * to force auto-detection)
+ * @param[in] baseDir direction of paragraph (specify FZ_BIDI_NEUTRAL to force auto-detection)
* @param[in] callback function to be called for each fragment
* @param[in] arg data to be passed to the callback function